summaryrefslogtreecommitdiffhomepage
path: root/test/tc_package.rb
diff options
context:
space:
mode:
authorVladimir Kochnev <[email protected]>2019-03-09 19:49:27 +0300
committerVladimir Kochnev <[email protected]>2019-10-02 18:06:39 +0300
commit09469669ccadf8580643eae8352372e92e1ddbb0 (patch)
tree35514f7979ee3abcbadbb416710c0577b47c924a /test/tc_package.rb
parent913003eaf0456e4645cad91f2622354deae10841 (diff)
downloadcaxlsx-09469669ccadf8580643eae8352372e92e1ddbb0.tar.gz
caxlsx-09469669ccadf8580643eae8352372e92e1ddbb0.zip
Cache relationship in Hash rather than in Array.
Also cacle only ids, not entire instances.
Diffstat (limited to 'test/tc_package.rb')
-rw-r--r--test/tc_package.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/tc_package.rb b/test/tc_package.rb
index 4bd0d429..1e5ce322 100644
--- a/test/tc_package.rb
+++ b/test/tc_package.rb
@@ -236,8 +236,8 @@ class TestPackage < Test::Unit::TestCase
# this is just a roundabout guess for a package as it is build now
# in testing.
assert(stream.size > 80000)
- # Cached instances should be cleared
- assert(Axlsx::Relationship.instances.empty?)
+ # Cached ids should be cleared
+ assert(Axlsx::Relationship.ids_cache.empty?)
end
def test_encrypt